@@ -1,6 +1,6 @@
-from saq.job import Job, Status
+from saq.job import CronJob, Job, Status
 from saq.queue import Queue
 from saq.worker import Worker
 
 
-__version__ = "0.3.1"
+__version__ = "0.4.0"
